Learn R Programming

trajeR (version 1.0)

dataNORM01: Simulated CNORM Dataset (data01)

Description

The data01 dataset is a simulated dataset included in the package. It contains 500 trajectories with 10 time-points each, simulating a 3-group solution. The parameters for the groups are summarized in the table below:

ParameterGroup 1Group 2Group 3
\(\beta_{k0}\)2.7977.00019.545
\(\beta_{k1}\)8.809-0.297-0.407
\(\beta_{k2}\)-3.2010.4630.026
\(\beta_{k3}\)0.000-0.0210.000
\(\pi_k\)0.320.540.14
\(\sigma_k\)4.0004.0004.000

Usage

dataNORM01

Arguments

Format

A data frame with 500 rows and 43 columns:

Columns 2:11

Matrix of real numbers (variable of interest, Y).

Columns 12:21

Matrix of time points (1 to 10, A).

Columns 22:31

Matrix of binary values (0 or 1, time-dependent covariate W).

Columns 32:41

Matrix of real numbers (additional time-dependent covariate W).

Columns 42:43

Matrix of binary values (0 or 1, covariate X).

Details

The dataset includes the following variables:

  • Y (columns 2:11): Matrix of real numbers representing the variable of interest.

  • A (columns 12:21): Matrix of time points (1 to 10).

  • W (columns 22:31): Matrix with values 0 and 1, indicating the presence or absence of a characteristic.

  • W (columns 32:41): Matrix of real numbers (additional time-dependent covariate).

  • X (columns 42:43): Matrix with values 0 and 1, influencing group membership probability.