| plotrajeR | R Documentation |
A generic plotting function for objects of class 'Trajectory.*'. It visualizes both individual and average group trajectories.
plotrajeR(Obj, ...)
Obj |
A trajectory object returned by the |
... |
Other parameters passed to the specific plot methods. |
This function is called for its side effect of creating a plot. It does not return any value.
# See examples for specific methods like plotrajeR.Trajectory.CNORM
data <- read.csv(system.file("extdata", "CNORM2gr.csv", package = "trajeR"))
sol <- trajeR(Y = data[, 2:6], A = data[, 7:11], Risk = data[, 12, drop = FALSE],
degre = c(2, 2), Model = "CNORM", Method = "EM")
plotrajeR(sol)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.