Learn R Programming

trajeR (version 1.0)

plotrajeR.Trajectory.POIS: Plot Method for POIS Trajectory Objects

Description

Plots the trajectories for a Poisson model fitted by `trajeR`.

Usage

# S3 method for Trajectory.POIS
plotrajeR(
  Obj,
  plotcov = NULL,
  dec = 0,
  col = "black",
  Y = NULL,
  A = NULL,
  Risk = NULL,
  TCOV = NULL,
  mean = FALSE,
  alpha = 1,
  ...
)

Value

a graphic.

Arguments

Obj

An object of class `Trajectory.POIS`.

plotcov

An optional vector or matrix of time-dependent covariates.

dec

A numeric value controlling the amount of jitter applied to data points.

col

An optional vector of colors.

Y

The original response variable matrix. If provided, individual trajectories are plotted.

A

The original time variable matrix.

Risk

Optional. The original risk covariate matrix.

TCOV

Matrix or Formula. An optional matrix (or one-sided formula) containing time-dependent covariates that influence the trajectories.

mean

Logical. If `TRUE`, plots the mean trajectory for each group.

alpha

A numeric value for the transparency of individual trajectory lines.

...

Other graphical parameters passed to `plot`.