Plots the trajectories for a Zero-Inflated Poisson (ZIP) model fitted by `trajeR`.
# S3 method for Trajectory.ZIP
plotrajeR(
Obj,
plotcov = NULL,
dec = 0,
col = "black",
Y = NULL,
A = NULL,
Risk = NULL,
TCOV = NULL,
mean = FALSE,
alpha = 1,
...
)a graphic.
An object of class `Trajectory.ZIP`.
An optional vector or matrix of time-dependent covariates.
A numeric value controlling the amount of jitter applied to data points.
An optional vector of colors.
The original response variable matrix.
The original time variable matrix.
Optional. The original risk covariate matrix.
Matrix or Formula. An optional matrix (or one-sided formula) containing time-dependent covariates that influence the trajectories.
Logical. If `TRUE`, plots the mean trajectory for each group.
A numeric value for the transparency of individual trajectory lines.
Other graphical parameters passed to `plot`.