| print.Trajectory.CNORM | R Documentation |
Displays a summary of a censored normal trajectory model fitted by 'trajeR'.
## S3 method for class 'Trajectory.CNORM'
print(x, ...)
x |
An object of class 'Trajectory.CNORM'. |
... |
Further arguments passed to or from other methods (not currently used). |
Invisibly returns the original object 'x'.
data <- read.csv(system.file("extdata", "CNORM2gr.csv", package = "trajeR"))
data <- as.matrix(data)
sol <- trajeR(Y = data[, 2:6], A = data[, 7:11], degre = c(2, 2), Model = "CNORM", Method = "EM")
sol
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.