print.Trajectory.LOGIT: Print Method for a 'Trajectory.LOGIT' Object

View source: R/PrintTrajeR.R

print.Trajectory.LOGITR Documentation

Print Method for a 'Trajectory.LOGIT' Object

Description

Displays a summary of a logistic trajectory model fitted by 'trajeR'.

Usage

## S3 method for class 'Trajectory.LOGIT'
print(x, ...)

Arguments

x

An object of class 'Trajectory.LOGIT'.

...

Further arguments passed to or from other methods (not currently used).

Value

Invisibly returns the original object 'x'.

Examples

data <- read.csv(system.file("extdata", "LOGIT2gr.csv", package = "trajeR"))
data <- as.matrix(data)
sol <- trajeR(Y = data[, 2:6], A = data[, 7:11], degre = c(1, 2), Model = "LOGIT", Method = "L")
sol

trajeR documentation built on Aug. 4, 2026, 1:09 a.m.