View source: R/model_adequacy.R
| ConfIntT | R Documentation |
Calculates confidence intervals for the estimated group membership probabilities using a parametric bootstrap method. It simulates new theta parameters from a normal distribution based on the estimated theta and their standard errors.
ConfIntT(sol, Y, A, nb = 10000, alpha = 0.98)
sol |
A trajectory object returned by the |
Y |
The response variable matrix, as used in the 'trajeR' call. |
A |
The time variable matrix, as used in the 'trajeR' call. |
nb |
An integer. The number of repetitions in the bootstrap method. |
alpha |
A number. The significance level for the confidence interval (e.g., 0.05 for a 95% CI). |
A matrix with two rows (lower and upper bounds) and a column for each group, containing the confidence intervals for the estimated probabilities.
data <- read.csv(system.file("extdata", "CNORM2gr.csv", package = "trajeR"))
sol <- trajeR(Y = data[, 2:6], A = data[, 7:11], degre = c(2, 2), Model = "CNORM", Method = "L")
ConfIntT(sol, Y = data[, 2:6], A = data[, 7:11])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.