Learn R Programming

trajeR (version 1.0)

ConfIntT: Bootstrap Confidence Intervals for Group Membership Probabilities

Description

Calculates confidence intervals for the estimated group membership probabilities using a parametric bootstrap method. It simulates new theta parameters from a normal distribution based on the estimated theta and their standard errors.

Usage

ConfIntT(sol, Y, A, nb = 10000, alpha = 0.98)

Value

A matrix with two rows (lower and upper bounds) and a column for each group, containing the confidence intervals for the estimated probabilities.

Arguments

sol

A trajectory object returned by the trajeR function.

Y

The response variable matrix, as used in the `trajeR` call.

A

The time variable matrix, as used in the `trajeR` call.

nb

An integer. The number of repetitions in the bootstrap method.

alpha

A number. The significance level for the confidence interval (e.g., 0.05 for a 95% CI).

Examples

Run this code
data <- read.csv(system.file("extdata", "CNORM2gr.csv", package = "trajeR"))
sol <- trajeR(Y = data[, 2:6], A = data[, 7:11], degre = c(2, 2), Model = "CNORM", Method = "L")
ConfIntT(sol, Y = data[, 2:6], A = data[, 7:11])

Run the code above in your browser using DataLab