View source: R/model_adequacy.R
| OCC | R Documentation |
The Odds of Correct Classification (OCC) compares the odds of correct assignment using the model's posterior probabilities against the odds of assignment based on the estimated group proportions alone. A high OCC value suggests that the model provides a much better classification than a random assignment.
OCC(sol, Y, A)
sol |
A trajectory object returned by the |
Y |
The response variable matrix, as used in the 'trajeR' call. |
A |
The time variable matrix, as used in the 'trajeR' call. |
A named numeric vector of the same length as the number of groups, containing the OCC for each group.
data <- read.csv(system.file("extdata", "CNORM2gr.csv", package = "trajeR"))
data <- as.matrix(data)
sol <- trajeR(Y = data[, 2:6], A = data[, 7:11], Risk = data[, 12, drop = FALSE],
degre = c(2, 2), Model = "CNORM", Method = "EM")
OCC(sol, Y = data[, 2:6], A = data[, 7:11])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.