Learn R Programming

trajeR (version 1.0)

adequacy: Model Adequacy Assessment

Description

Provides a summary table of model adequacy metrics, including estimated group probabilities, confidence intervals, assignment proportions, Average Posterior Probability (AvePP), and Odds of Correct Classification (OCC).

Usage

adequacy(sol, Y, A, nb = 10000, alpha = 0.98)

Value

A table of reals. A table with 5 rows: the estimate probabilities, the two bounds of the confidence interval, the proportion of assignment, the Average Posterior Probability and the Odds of Correct Classification.

Arguments

sol

A trajectory object returned by the trajeR function.

Y

The response variable matrix, as used in the `trajeR` call.

A

The time variable matrix, as used in the `trajeR` call.

nb

Integer. The number of repetitions for the bootstrap confidence interval.

alpha

Real. The degree of confidence of the interval.

Examples

Run this code
data <- read.csv(system.file("extdata", "CNORM2gr.csv", package = "trajeR"))
data <- as.matrix(data)
sol <- trajeR(Y = data[, 2:6], A = data[, 7:11], degre = c(2, 2), Model = "CNORM", Method = "L")
adequacy(sol, Y = data[, 2:6], A = data[, 7:11])

Run the code above in your browser using DataLab