| data_LOGIT | R Documentation |
This dataset is a simulated dataset for use with the trajeR.LOGIT function,
which is an internal function to fit Logistic trajectory models.
This dataset is likely used to demonstrate the functionality of the trajeR.LOGIT model.
The LOGIT model is suitable for binary or categorical outcome variables, often representing probabilities or classifications.
data_LOGIT
Expected to be a data format compatible with the trajeR.LOGIT function,
typically matrices for the response variable (Y), time variable (A),
and potentially covariates (X, TCOV).
Simulated data for illustrative purposes of trajectory analysis using the trajeR.LOGIT model.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.