| data_ZIP | R Documentation |
This dataset is a simulated dataset for use with the trajeR.ZIP function,
which is an internal function to fit Zero-Inflated Poisson trajectory models.
This dataset is likely used to demonstrate the functionality of the trajeR.ZIP model.
The ZIP model is appropriate for count data that has an excess of zero observations, often found in fields like public health or ecology.
data_ZIP
Expected to be a data format compatible with the trajeR.ZIP function,
typically matrices for the response variable (Y), time variable (A),
and potentially covariates (X, TCOV).
Simulated data for illustrative purposes of trajectory analysis using the trajeR.ZIP model.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.