Learn R Programming

trajeR (version 1.0)

plotrajeR: Plot Group Trajectories from a trajeR Model

Description

A generic plotting function for objects of class `Trajectory.*`. It visualizes both individual and average group trajectories.

Usage

plotrajeR(Obj, ...)

Value

This function is called for its side effect of creating a plot. It does not return any value.

Arguments

Obj

A trajectory object returned by the trajeR function.

...

Other parameters passed to the specific plot methods.

Examples

Run this code
# See examples for specific methods like plotrajeR.Trajectory.CNORM
data <- read.csv(system.file("extdata", "CNORM2gr.csv", package = "trajeR"))
sol <- trajeR(Y = data[, 2:6], A = data[, 7:11], Risk = data[, 12, drop = FALSE],
              degre = c(2, 2), Model = "CNORM", Method = "EM")
plotrajeR(sol)

Run the code above in your browser using DataLab