| plotrajeR.Trajectory.CNORM | R Documentation |
Plots the trajectories for a Censored Normal model fitted by 'trajeR'.
## S3 method for class 'Trajectory.CNORM'
plotrajeR(
Obj,
plotcov = NULL,
col = "black",
Y = NULL,
A = NULL,
Risk = NULL,
mean = FALSE,
alpha = 1,
...
)
Obj |
An object of class 'Trajectory.CNORM'. |
plotcov |
An optional vector or matrix of time-dependent covariates to visualize their effect on trajectories. |
col |
An optional vector of colors. If its length is '2 * ng', the first 'ng' colors are for individual trajectories and the next 'ng' are for the mean trajectories. |
Y |
The original response variable matrix used to fit the model. If provided, individual trajectories are plotted. |
A |
The original time variable matrix used to fit the model. |
Risk |
Optional. The original risk covariate matrix used to fit the model. |
mean |
Logical. If 'TRUE', the mean trajectory for each group (based on assigned individuals) is plotted as a dashed line. |
alpha |
A numeric value between 0 and 1 for the transparency of individual trajectory lines. |
... |
Other graphical parameters passed to 'plot'. |
a graphic.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.