Plots the trajectories for a Censored Normal model fitted by `trajeR`.
# S3 method for Trajectory.CNORM
plotrajeR(
Obj,
plotcov = NULL,
col = "black",
Y = NULL,
A = NULL,
Risk = NULL,
mean = FALSE,
alpha = 1,
...
)a graphic.
An object of class `Trajectory.CNORM`.
An optional vector or matrix of time-dependent covariates to visualize their effect on trajectories.
An optional vector of colors. If its length is `2 * ng`, the first `ng` colors are for individual trajectories and the next `ng` are for the mean trajectories.
The original response variable matrix used to fit the model. If provided, individual trajectories are plotted.
The original time variable matrix used to fit the model.
Optional. The original risk covariate matrix used to fit the model.
Logical. If `TRUE`, the mean trajectory for each group (based on assigned individuals) is plotted as a dashed line.
A numeric value between 0 and 1 for the transparency of individual trajectory lines.
Other graphical parameters passed to `plot`.