| plotrajeR.Trajectory.LOGIT | R Documentation |
Plots the trajectories for a Logistic model fitted by 'trajeR'.
## S3 method for class 'Trajectory.LOGIT'
plotrajeR(
Obj,
plotcov = NULL,
dec = 0,
col = "black",
Y = NULL,
A = NULL,
Risk = NULL,
mean = FALSE,
alpha = 1,
...
)
Obj |
An object of class 'Trajectory.LOGIT'. |
plotcov |
An optional vector or matrix of time-dependent covariates. |
dec |
A numeric value controlling the amount of jitter applied to data points for better visualization. |
col |
An optional vector of colors for individual points and mean trajectories. |
Y |
The original response variable matrix. If provided, individual data points are jittered and plotted. |
A |
The original time variable matrix. |
Risk |
Optional. The original risk covariate matrix. |
mean |
Logical. If 'TRUE', plots the mean of the observed data for each group. |
alpha |
A numeric value for the transparency of individual trajectory lines. |
... |
Other graphical parameters passed to 'plot'. |
a graphic.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.