Plots the trajectories for a Logistic model fitted by `trajeR`.
# S3 method for Trajectory.LOGIT
plotrajeR(
Obj,
plotcov = NULL,
dec = 0,
col = "black",
Y = NULL,
A = NULL,
Risk = NULL,
mean = FALSE,
alpha = 1,
...
)a graphic.
An object of class `Trajectory.LOGIT`.
An optional vector or matrix of time-dependent covariates.
A numeric value controlling the amount of jitter applied to data points for better visualization.
An optional vector of colors for individual points and mean trajectories.
The original response variable matrix. If provided, individual data points are jittered and plotted.
The original time variable matrix.
Optional. The original risk covariate matrix.
Logical. If `TRUE`, plots the mean of the observed data for each group.
A numeric value for the transparency of individual trajectory lines.
Other graphical parameters passed to `plot`.