Plots the trajectories for a Poisson model fitted by `trajeR`.
# S3 method for Trajectory.POIS
plotrajeR(
Obj,
plotcov = NULL,
dec = 0,
col = "black",
Y = NULL,
A = NULL,
Risk = NULL,
TCOV = NULL,
mean = FALSE,
alpha = 1,
...
)a graphic.
An object of class `Trajectory.POIS`.
An optional vector or matrix of time-dependent covariates.
A numeric value controlling the amount of jitter applied to data points.
An optional vector of colors.
The original response variable matrix. If provided, individual trajectories are plotted.
The original time variable matrix.
Optional. The original risk covariate matrix.
Matrix or Formula. An optional matrix (or one-sided formula) containing time-dependent covariates that influence the trajectories.
Logical. If `TRUE`, plots the mean trajectory for each group.
A numeric value for the transparency of individual trajectory lines.
Other graphical parameters passed to `plot`.