Learn R Programming

trajeR (version 1.0)

print.Trajectory.CNORM: Print Method for a `Trajectory.CNORM` Object

Description

Displays a summary of a censored normal trajectory model fitted by `trajeR`.

Usage

# S3 method for Trajectory.CNORM
print(x, ...)

Value

Invisibly returns the original object `x`.

Arguments

x

An object of class `Trajectory.CNORM`.

...

Further arguments passed to or from other methods (not currently used).

Examples

Run this code
data <- read.csv(system.file("extdata", "CNORM2gr.csv", package = "trajeR"))
data <- as.matrix(data)
sol <- trajeR(Y = data[, 2:6], A = data[, 7:11], degre = c(2, 2), Model = "CNORM", Method = "EM")
sol

Run the code above in your browser using DataLab