| print.Trajectory.LOGIT | R Documentation |
Displays a summary of a logistic trajectory model fitted by 'trajeR'.
## S3 method for class 'Trajectory.LOGIT'
print(x, ...)
x |
An object of class 'Trajectory.LOGIT'. |
... |
Further arguments passed to or from other methods (not currently used). |
Invisibly returns the original object 'x'.
data <- read.csv(system.file("extdata", "LOGIT2gr.csv", package = "trajeR"))
data <- as.matrix(data)
sol <- trajeR(Y = data[, 2:6], A = data[, 7:11], degre = c(1, 2), Model = "LOGIT", Method = "L")
sol
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.