Learn R Programming

trajeR (version 1.0)

print.Trajectory.LOGIT: Print Method for a `Trajectory.LOGIT` Object

Description

Displays a summary of a logistic trajectory model fitted by `trajeR`.

Usage

# S3 method for Trajectory.LOGIT
print(x, ...)

Value

Invisibly returns the original object `x`.

Arguments

x

An object of class `Trajectory.LOGIT`.

...

Further arguments passed to or from other methods (not currently used).

Examples

Run this code
data <- read.csv(system.file("extdata", "LOGIT2gr.csv", package = "trajeR"))
data <- as.matrix(data)
sol <- trajeR(Y = data[, 2:6], A = data[, 7:11], degre = c(1, 2), Model = "LOGIT", Method = "L")
sol

Run the code above in your browser using DataLab